==> nightfall-1.42.tar.gz: nightfall-1.42/LightLimits.h <==

/* mass ratio */
#define LIM_MQ_L 0.0001
#define LIM_MQ_H 10000.0
#define LIM_MQO_L 0.003
#define LIM_MQO_H 50.0

/* inclination */
#define LIM_IN_L 0.0
#define LIM_IN_H 1.5707963

/* fill factor */
#define LIM_RF_L 0.001
#define LIM_RF_H 1.0
#define LIM_RO_L 1.0001
#define LIM_RO_H 1.3

/* temperature */
#define LIM_TM_L 3000.
#define LIM_TM_H 35000.
#define LIM_TB_L 350.
#define LIM_TB_H 350000.

/* disk parameters */
#define LIM_OR_L 0.0
#define LIM_OR_H 1.0
#define LIM_IR_L 0.0
#define LIM_IR_H 0.61
#define LIM_TI_L 0.0
#define LIM_TI_H 30.0
#define LIM_TH_L 0.0
#define LIM_TH_H 1.0
#define LIM_WA_L 0.0
#define LIM_WA_H 90.0
#define LIM_HR_L 0.0
#define LIM_HR_H 1.0
/* Has to be set to realistic limits TBD MK*/
#define LIM_DT_L 500.0
#define LIM_DT_H 1000000.0

/* elliptic orbit */
#define LIM_EX_L 0.0
#define LIM_EX_H 0.95
#define LIM_PA_L -360.
#define LIM_PA_H 360.

/* asynchron rotation */
#define LIM_FR_L 0.01
#define LIM_FR_H 10.0

/* spots */
#define LIM_SLA_L -90.
#define LIM_SLA_H  90.
#define LIM_SLO_L -360.
#define LIM_SLO_H  360.
#define LIM_SRA_L  1.0
#define LIM_SRA_H  180.
#define LIM_SDF_L  0.5
#define LIM_SDF_H  2.0

/* mass/distance */
#define LIM_MASS_L 0.0
#define LIM_MASS_H 3.978e32    /* 100 solar masses */
#define LIM_PERI_L 0.0
#define LIM_PERI_H 2.2226262e9 /* 70 years         */
#define LIM_DIST_L 0.0
#define LIM_DIST_H 1.496e14    /* 1000 au          */

/* third Light */
#define LIM_3L_L 0.0
#define LIM_3L_H 0.98

/* line profile */
#define LIM_PRF_L 300.0
#define LIM_PRF_H 5000.0

==> nightfall-1.52.tar.gz: nightfall-1.52/LightLimits.h <==

/* mass ratio */
#define LIM_MQ_L 0.0001
#define LIM_MQ_H 10000.0
#define LIM_MQO_L 0.003
#define LIM_MQO_H 50.0

/* inclination */
#define LIM_IN_L 0.0
#define LIM_IN_H 1.5707963

/* log g */
#define LIM_LOGG_L 3.5
#define LIM_LOGG_H 5.0

/* fill factor */
#define LIM_RF_L 0.001
#define LIM_RF_H 1.0
#define LIM_RO_L 1.0001
#define LIM_RO_H 1.3

/* temperature */
#define LIM_TM_L 2000.
#define LIM_TM_H(arg) ModelLimits(arg)
#define LIM_TB_L 350.
#define LIM_TB_H 350000.

/* disk parameters */
#define LIM_OR_L 0.0
#define LIM_OR_H 1.0
#define LIM_IR_L 0.0
#define LIM_IR_H 0.61
#define LIM_TI_L 0.0
#define LIM_TI_H 30.0
#define LIM_TH_L 0.0
#define LIM_TH_H 1.0
#define LIM_WA_L 0.0
#define LIM_WA_H 90.0
#define LIM_HR_L 0.0
#define LIM_HR_H 1.0
/* Has to be set to realistic limits TBD MK*/
#define LIM_DT_L 500.0
#define LIM_DT_H 1000000.0

/* elliptic orbit */
#define LIM_EX_L 0.0
#define LIM_EX_H 0.95
#define LIM_PA_L -360.
#define LIM_PA_H 360.

/* asynchron rotation */
#define LIM_FR_L 0.01
#define LIM_FR_H 10.0

/* spots */
#define LIM_SLA_L -90.
#define LIM_SLA_H  90.
#define LIM_SLO_L -360.
#define LIM_SLO_H  360.
#define LIM_SRA_L  1.0
#define LIM_SRA_H  180.
#define LIM_SDF_L  0.5
#define LIM_SDF_H  2.0

/* mass/distance */
#define LIM_MASS_L 0.0
#define LIM_MASS_H 3.978e32    /* 100 solar masses */
#define LIM_PERI_L 0.0
#define LIM_PERI_H 2.2226262e9 /* 70 years         */
#define LIM_DIST_L 0.0
#define LIM_DIST_H 1.496e14    /* 1000 au          */

/* third Light */
#define LIM_3L_L 0.0
#define LIM_3L_H 0.98

/* line profile */
#define LIM_PRF_L 300.0
#define LIM_PRF_H 5000.0
